@@ -9,20 +9,19 @@ import astroid
 from pylint.checkers import BaseChecker
 from pylint.interfaces import IAstroidChecker
 
-from pylint_utils import get_binary_op_complexity
-
+from .pylint_utils import get_binary_op_complexity
 
 
 class LogicOpComplexityChecker(BaseChecker):
     __implements__ = IAstroidChecker
 
-    name = 'logic-op-complexity'
+    name = "logic-op-complexity"
     priority = -1
     msgs = {
-        'E1074': (
-            'Complexity of inline logic statement should be 3 or lower.',
-            'high-logic-op-complexity',
-            'This statement has a high complexity and should be split into several smaller statements assigned with descriptive variable names.'
+        "E1074": (
+            "Complexity of inline logic statement should be 3 or lower.",
+            "high-logic-op-complexity",
+            "This statement has a high complexity and should be split into several smaller statements assigned with descriptive variable names.",
         ),
     }
 
@@ -42,7 +41,7 @@ class LogicOpComplexityChecker(BaseChecker):
 
     def visit_binop(self, node):
         if get_binary_op_complexity(node) > 3:
-            self.add_message('high-logic-op-complexity', node=node)
+            self.add_message("high-logic-op-complexity", node=node)
 
     def leave_functiondef(self, node):
         self._function_stack.pop()
