@@ -147,11 +147,27 @@ def get_length(arg):
         total_length += base_length
         return total_length
     if isinstance(arg, astroid.nodes.Slice):
-        base_length = 3 # brackets and ':'
         total_length = 0
-        for value in arg.values:
-            total_length += get_length(value)
-        total_length += base_length
+        number_of_colon = 0
+        try:
+            lower_length = get_length(arg.lower)
+        except TypeError:
+            lower_length = 0
+        try:
+            step_length = get_length(arg.step)
+
+        except TypeError:
+            step_length = 0
+        try:
+            upper_length = get_length(arg.upper)
+        except TypeError:
+            upper_length = 0
+        if lower_length >= 1 or upper_length >= 1:
+            number_of_colon += 1
+        # step should always have two
+        if step_length >= 1:
+            number_of_colon = 2
+        total_length += lower_length + step_length + upper_length + number_of_colon
         return total_length
     if isinstance(arg, astroid.nodes.UnaryOp):
         base_length = 1 # operator
